#!/bin/bash

function check_sudo {
  if ! [ -x "$(command -v sudo)" ]; then
    echo "For successful installation you need to have sudo installed"
    exit 1
  fi
}

check_sudo 

function check_lsb_release {
  if ! [ -x "$(command -v lsb_release)" ]; then
    sudo yum install redhat-lsb-core
  fi
}


ARCH=$(uname -m | sed 's/x86_//;s/i[3-6]86/32/')

if [ -f /etc/lsb-release ]; then
  . /etc/lsb-release
  OS=$DISTRIB_ID
  VER=$DISTRIB_RELEASE
elif [ -f /etc/debian_version ]; then
  OS=Debian
  VER=$(cat /etc/debian_version)
elif [ -f /etc/redhat-release ]; then
  check_lsb_release
  OS=$(lsb_release -is)
  VER=$(lsb_release -sr)
elif [ -f /etc/SuSE-release ]; then
  OS=Suse
  VER=$(cat /etc/SuSE-release | grep VERSION | awk '{print $3}')
elif [ -f /etc/os-release ]; then
  OS=$(cat /etc/os-release | grep NAME | awk '{print $3}')
  VER=$(cat /etc/os-release | grep VERSION | awk '{print $3}')
else
  OS=$(uname -s)
  VER=$(uname -r)
fi
  
DESKTOP=""
if [ "$XDG_CURRENT_DESKTOP" = "" ]; then
  DESKTOP=$(echo "$XDG_DATA_DIRS" | sed 's/.*\(xfce\|kde\|gnome\).*/\1/')
else
  DESKTOP=$XDG_CURRENT_DESKTOP
fi
echo "$DESKTOP"

SUCCESS=""
function install_rpm {
  #dnf distro-sync
  sudo yum install -y ./"${PACKAGE_NAME}"*.rpm freetype.i686
  if [ $? -eq 0 ]; then
    SUCCESS="OK"
  fi
}

function install_deb {
  sudo apt -y update
  sudo apt-get -y -f install
  sudo dpkg --add-architecture i386
  sudo dpkg --configure -a
  sudo apt-get update
  sudo apt-get -y install binutils 
  sudo dpkg -i ./"${PACKAGE_NAME}"*.deb || true
  sudo apt-get -y -f install
  if [ $? -eq 0 ]; then
    SUCCESS="OK"
  fi
}

function install_rpm_suse {
  sudo zypper install -n ./"${PACKAGE_NAME}"*.rpm binutils libfreetype6-32bit
  if [ $? -eq 0 ]; then
    SUCCESS="OK"
  fi
}


case "$OS" in
Fedora|Centos|CentOS)
  install_rpm
  ;;
Ubuntu|Debian)
  install_deb
  ;;
Suse)
  install_rpm_suse
  ;;
*)
  echo "$OS"
  echo "Wrong linux distribution or desktop environment"
  notify-send -u critical "Wrong linux distribution or desktop environment"
  ;;
esac

if [ "$DESKTOP" = "KDE" ] && [ "$SUCCESS" = "OK" ]; then
  notify-send -u critical "MSPA" "Please log out and log in again"
fi
